@@ -38,10 +38,11 @@ class JuK : public KXmlGuiWindow
 public:
     JuK(QWidget* parent = 0);
     virtual ~JuK();
-    virtual KActionCollection *actionCollection() const;
 
     static JuK* JuKInstance();
 
+    PlayerManager *playerManager() const;
+
     // Use a null cover for failure
     void coverDownloaded(const QPixmap &cover);
 
@@ -68,7 +69,6 @@ private slots:
     void slotShowHide();
     void slotAboutToQuit();
     void slotQuit();
-    void slotPlaybackStopped();
     void slotToggleSystemTray(bool enabled);
     void slotEditKeys();
     void slotConfigureTagGuesser();
