@@ -1251,8 +1251,6 @@ void Playlist::applySharedSettings()
 
 void Playlist::read(QDataStream &s)
 {
-    QString buffer;
-
     s >> m_playlistName
       >> m_fileName;
 
@@ -1260,6 +1258,9 @@ void Playlist::read(QDataStream &s)
     if(m_playlistName.isEmpty())
         throw BICStreamException();
 
+    // Do not sort. Add the files in the order they were saved.
+    setSorting(columns() + 1);
+
     QStringList files;
     s >> files;
 
@@ -1705,7 +1706,10 @@ void Playlist::setup()
     m_headerMenu = m_columnVisibleAction->menu();
 
     // TODO: Determine if other stuff in setup must happen before slotInitialize().
-    QTimer::singleShot(0, this, SLOT(slotInitialize()));
+
+    // Explicitly call slotInitialize() so that the columns are added before
+    // SharedSettings::apply() sets the visible and hidden ones.
+    slotInitialize();
 }
 
 void Playlist::loadFile(const QString &fileName, const QFileInfo &fileInfo)
