@@ -62,9 +62,9 @@ using namespace ActionCollection;
 // PlaylistBox public methods
 ////////////////////////////////////////////////////////////////////////////////
 
-PlaylistBox::PlaylistBox(QWidget *parent, QStackedWidget *playlistStack) :
+PlaylistBox::PlaylistBox(PlayerManager *player, QWidget *parent, QStackedWidget *playlistStack) :
     K3ListView(parent),
-    PlaylistCollection(playlistStack),
+    PlaylistCollection(player, playlistStack),
     m_viewModeIndex(0),
     m_hasSelection(false),
     m_doingMultiSelect(false),
@@ -158,6 +158,12 @@ PlaylistBox::PlaylistBox(QWidget *parent, QStackedWidget *playlistStack) :
 
     m_savePlaylistTimer = 0;
 
+    KToggleAction *historyAction =
+        new KToggleAction(KIcon("view-history"), i18n("Show &History"), ActionCollection::actions());
+    ActionCollection::actions()->addAction("showHistory", historyAction);
+    connect(historyAction, SIGNAL(triggered(bool)),
+            this, SLOT(slotSetHistoryPlaylistEnabled(bool)));
+
     m_showTimer = new QTimer(this);
     connect(m_showTimer, SIGNAL(timeout()), SLOT(slotShowDropTarget()));
 
@@ -244,6 +250,11 @@ void PlaylistBox::slotPlaylistDataChanged()
         m_savePlaylistTimer->start(); // Restarts the timer if it's already running.
 }
 
+void PlaylistBox::slotSetHistoryPlaylistEnabled(bool enable)
+{
+    setHistoryPlaylistEnabled(enable);
+}
+
 void PlaylistBox::setupPlaylist(Playlist *playlist, const QString &iconName)
 {
     setupPlaylist(playlist, iconName, 0);
@@ -389,7 +400,7 @@ void PlaylistBox::setDynamicListsFrozen(bool frozen)
 
 void PlaylistBox::slotSavePlaylists()
 {
-    kDebug(65432) << "Auto-saving playlists.\n";
+    kDebug() << "Auto-saving playlists.\n";
 
     PlaylistList l;
     CollectionList *collection = CollectionList::instance();
@@ -405,7 +416,7 @@ void PlaylistBox::slotSavePlaylists()
 void PlaylistBox::slotShowDropTarget()
 {
     if(!m_dropItem) {
-        kError(65432) << "Trying to show the playlist of a null item!\n";
+        kError() << "Trying to show the playlist of a null item!\n";
         return;
     }
 
@@ -675,7 +686,7 @@ void PlaylistBox::slotDoubleClicked(Q3ListViewItem *item)
     PlaylistItem *next = manager->nextItem(); // Allow manager to choose
 
     if(next) {
-        PlayerManager::instance()->play(next->file());
+        emit startFilePlayback(next->file());
         playlistItem->playlist()->setPlaying(next);
     }
     else
