@@ -47,12 +47,13 @@ SearchLine::SearchLine(QWidget *parent, bool simple)
     m_searchFieldsBox(0)
 {
     QHBoxLayout *layout = new QHBoxLayout(this);
+    layout->setMargin(0);
     layout->setSpacing(5);
 
     if(!m_simple) {
         m_searchFieldsBox = new KComboBox(this);
         layout->addWidget(m_searchFieldsBox);
-        m_searchFieldsBox->setObjectName( "searchFields" );
+        m_searchFieldsBox->setObjectName( QLatin1String( "searchFields" ) );
         connect(m_searchFieldsBox, SIGNAL(activated(int)),
                 this, SIGNAL(signalQueryChanged()));
     }
